@@ -1,5 +1,5 @@
 /*
-  Copyright (c) 2013 Montel Laurent <montel@kde.org>
+  Copyright (c) 2013-2017 Montel Laurent <montel@kde.org>
 
   This library is free software; you can redistribute it and/or modify it
   under the terms of the GNU Library General Public License as published by
@@ -34,7 +34,7 @@ public:
     bool sendSms(const QString &number, const QString &text) override;
 private:
     bool initializeEkiga();
-    QDBusInterface *mInterface;
+    QDBusInterface *mInterface = nullptr;
 };
 
 #endif // QEKIGADIALER_H
