@@ -20,22 +20,17 @@
 
 #include "qsflphonedialer.h"
 
-#include <KDBusConnectionPool>
-
 #include <KLocalizedString>
 
-#include <QDBusConnectionInterface>
-
 #include <QProcess>
 #include <QDBusConnection>
 #include <QDBusConnectionInterface>
-#include <QDBusInterface>
-#include <QDBusReply>
+#include <KDBusConnectionPool>
 
-#ifdef WIN32
-#include <windows.h>
-#else
+#if !defined(Q_OS_WIN)
 #include <unistd.h>
+#else
+#include <windows.h>
 #endif
 
 static bool isSflPhoneServiceRegistered()
@@ -76,10 +71,10 @@ bool QSflPhoneDialer::initializeSflPhone()
         const int runs = 100;
         for (int i = 0; i < runs; ++i) {
             if (!isSflPhoneServiceRegistered()) {
-#ifdef WIN32
-                Sleep(2000);
-#else
+#if !defined(Q_OS_WIN)
                 ::sleep(2);
+#else
+                Sleep(2000);
 #endif
             } else {
                 return true;
