@@ -17,8 +17,8 @@
     Boston, MA 02110-1301, USA.
 */
 
-#ifndef AKONADI_CONTACTSPRIVATE_EXPORT_H
-#define AKONADI_CONTACTSPRIVATE_EXPORT_H
+#ifndef AKONADICONTACT_PRIVATE_EXPORT_H
+#define AKONADICONTACT_PRIVATE_EXPORT_H
 
 #include "akonadi-contact_export.h"
 
