@@ -73,7 +73,7 @@ ContactLineEdit::ContactLineEdit(bool isReference, ContactCompletionModel::Colum
     QCompleter *completer = new QCompleter(filter, this);
     completer->setCompletionColumn(column);
     completer->setCaseSensitivity(Qt::CaseInsensitive);
-    connect(completer, SIGNAL(activated(QModelIndex)), SLOT(completed(QModelIndex)));
+    connect(completer, QOverload<const QModelIndex &>::of(&QCompleter::activated), this, QOverload<const QModelIndex &>::of(&ContactLineEdit::completed));
 
     setCompleter(completer);
 
@@ -121,7 +121,7 @@ public:
 
     QSize mButtonSize;
     const QIcon mIcon;
-    QAbstractItemView *mItemView;
+    QAbstractItemView *mItemView = nullptr;
 };
 
 ContactGroupEditorDelegate::ContactGroupEditorDelegate(QAbstractItemView *view, QObject *parent)
@@ -142,7 +142,7 @@ QWidget *ContactGroupEditorDelegate::createEditor(QWidget *parent, const QStyleO
     Q_UNUSED(option)
     if (index.column() == 0) {
         auto edit = new ContactLineEdit(isReference, ContactCompletionModel::EmailColumn, parent);
-        connect(edit, SIGNAL(completed(QWidget *)), SLOT(completed(QWidget *)));
+        connect(edit, SIGNAL(completed(QWidget*)), SLOT(completed(QWidget*)));
 
         return edit;
     } else {
@@ -153,8 +153,7 @@ QWidget *ContactGroupEditorDelegate::createEditor(QWidget *parent, const QStyleO
             return comboBox;
         } else {
             auto edit = new ContactLineEdit(isReference, ContactCompletionModel::EmailColumn, parent);
-            connect(edit, static_cast<void (ContactLineEdit::*)(QWidget *)>(&ContactLineEdit::completed),
-                    this, &ContactGroupEditorDelegate::completed);
+            connect(edit, QOverload<QWidget *>::of(&ContactLineEdit::completed), this, &ContactGroupEditorDelegate::completed);
             return edit;
         }
     }
