@@ -66,7 +66,9 @@ public:
         job->setProperty("row", row);
         job->fetchScope().fetchFullPayload();
 
-        mParent->connect(job, SIGNAL(result(KJob *)), SLOT(itemFetched(KJob *)));
+        mParent->connect(job, &ItemFetchJob::result, mParent, [this](KJob *job) {
+            itemFetched(job);
+        });
     }
 
     void itemFetched(KJob *job)
@@ -150,7 +152,7 @@ public:
         } while (foundEmpty);
     }
 
-    ContactGroupModel *mParent;
+    ContactGroupModel *mParent = nullptr;
     QVector<GroupMember> mMembers;
     KContacts::ContactGroup mGroup;
     QString mLastErrorMessage;
