@@ -114,13 +114,15 @@ public:
 
         // stop any running fetch job
         if (mParentCollectionFetchJob) {
-            mParent->disconnect(mParentCollectionFetchJob, SIGNAL(result(KJob *)), mParent, SLOT(slotParentCollectionFetched(KJob *)));
+            mParent->disconnect(mParentCollectionFetchJob, SIGNAL(result(KJob*)), mParent, SLOT(slotParentCollectionFetched(KJob*)));
             delete mParentCollectionFetchJob;
             mParentCollectionFetchJob = nullptr;
         }
 
         mParentCollectionFetchJob = new CollectionFetchJob(mCurrentItem.parentCollection(), CollectionFetchJob::Base, mParent);
-        mParent->connect(mParentCollectionFetchJob, SIGNAL(result(KJob *)), SLOT(slotParentCollectionFetched(KJob *)));
+        mParent->connect(mParentCollectionFetchJob, &CollectionFetchJob::result, mParent, [this](KJob *job) {
+            slotParentCollectionFetched(job);
+        });
     }
 
     void slotParentCollectionFetched(KJob *job)
@@ -139,16 +141,16 @@ public:
         updateView();
     }
 
-    ContactGroupViewer *mParent;
-    TextBrowser *mBrowser;
+    ContactGroupViewer *mParent = nullptr;
+    TextBrowser *mBrowser = nullptr;
     QString mCurrentGroupName;
     KContacts::Addressee::List mCurrentContacts;
     QString mCurrentAddressBookName;
     Item mCurrentItem;
-    ContactGroupExpandJob *mExpandJob;
-    CollectionFetchJob *mParentCollectionFetchJob;
-    AbstractContactGroupFormatter *mStandardContactGroupFormatter;
-    AbstractContactGroupFormatter *mContactGroupFormatter;
+    ContactGroupExpandJob *mExpandJob = nullptr;
+    CollectionFetchJob *mParentCollectionFetchJob = nullptr;
+    AbstractContactGroupFormatter *mStandardContactGroupFormatter = nullptr;
+    AbstractContactGroupFormatter *mContactGroupFormatter = nullptr;
 };
 
 ContactGroupViewer::ContactGroupViewer(QWidget *parent)
@@ -158,8 +160,9 @@ ContactGroupViewer::ContactGroupViewer(QWidget *parent)
     QVBoxLayout *layout = new QVBoxLayout(this);
     layout->setMargin(0);
 
-    connect(d->mBrowser, SIGNAL(anchorClicked(QUrl)),
-            this, SLOT(slotMailClicked(QUrl)));
+    connect(d->mBrowser, &TextBrowser::anchorClicked, this, [this](const QUrl &url) {
+        d->slotMailClicked(url);
+    });
 
     layout->addWidget(d->mBrowser);
 
@@ -203,12 +206,12 @@ void ContactGroupViewer::itemChanged(const Item &item)
     d->mCurrentItem = item;
 
     if (d->mExpandJob) {
-        disconnect(d->mExpandJob, SIGNAL(result(KJob *)), this, SLOT(_k_expandResult(KJob *)));
+        disconnect(d->mExpandJob, SIGNAL(result(KJob*)), this, SLOT(_k_expandResult(KJob*)));
         d->mExpandJob->kill();
     }
 
     d->mExpandJob = new ContactGroupExpandJob(group);
-    connect(d->mExpandJob, SIGNAL(result(KJob *)), SLOT(_k_expandResult(KJob *)));
+    connect(d->mExpandJob, SIGNAL(result(KJob*)), SLOT(_k_expandResult(KJob*)));
     d->mExpandJob->start();
 }
 
