@@ -59,9 +59,9 @@ ContactsTreeModel::~ContactsTreeModel()
 
 void ContactsTreeModel::setColumns(const Columns &columns)
 {
-    Q_EMIT beginResetModel();
+    beginResetModel();
     d->mColumns = columns;
-    Q_EMIT endResetModel();
+    endResetModel();
 }
 
 ContactsTreeModel::Columns ContactsTreeModel::columns() const
@@ -183,11 +183,9 @@ QVariant ContactsTreeModel::entityData(const Item &item, int column, int role) c
             {
                 const KContacts::ContactGroup group = item.payload<KContacts::ContactGroup>();
                 return group.name();
-                break;
             }
             default:
                 return QVariant();
-                break;
             }
         }
     }
