@@ -36,7 +36,6 @@
 #include <session.h>
 #include <kcontacts/addressee.h>
 #include <kcontacts/contactgroup.h>
-#include <KLineEdit>
 #include <KLocalizedString>
 
 #include <QTimer>
@@ -45,7 +44,7 @@
 #include <QKeyEvent>
 #include <QLabel>
 #include <QVBoxLayout>
-
+#include <QLineEdit>
 using namespace Akonadi;
 
 /**
@@ -73,7 +72,7 @@ protected:
     }
 
 private:
-    QWidget *mReceiver;
+    QWidget *mReceiver = nullptr;
 };
 
 /**
@@ -92,13 +91,13 @@ public:
 
     void init();
 
-    EmailAddressSelectionWidget *q;
-    QAbstractItemModel *mModel;
-    QLabel *mDescriptionLabel;
-    SearchLineEdit *mSearchLine;
-    Akonadi::EntityTreeView *mView;
-    EmailAddressSelectionProxyModel *mSelectionModel;
-    bool mShowOnlyContactWithEmail;
+    EmailAddressSelectionWidget *q = nullptr;
+    QAbstractItemModel *mModel = nullptr;
+    QLabel *mDescriptionLabel = nullptr;
+    SearchLineEdit *mSearchLine = nullptr;
+    Akonadi::EntityTreeView *mView = nullptr;
+    EmailAddressSelectionProxyModel *mSelectionModel = nullptr;
+    bool mShowOnlyContactWithEmail = false;
 };
 
 void EmailAddressSelectionWidget::Private::init()
@@ -157,7 +156,7 @@ void EmailAddressSelectionWidget::Private::init()
 
     mSearchLine->setFocus();
 
-    if (Akonadi::EntityTreeModel *etm = qobject_cast<Akonadi::EntityTreeModel*>(mModel)) {
+    if (Akonadi::EntityTreeModel *etm = qobject_cast<Akonadi::EntityTreeModel *>(mModel)) {
         QObject::connect(etm, &Akonadi::EntityTreeModel::collectionTreeFetched, mView, &QTreeView::expandAll);
     } else {
         QTimer::singleShot(1000, mView, &QTreeView::expandAll);
