@@ -70,7 +70,9 @@ public:
             job->fetchScope().fetchFullPayload();
             job->setProperty("preferredEmail", reference.preferredEmail());
 
-            mParent->connect(job, SIGNAL(result(KJob *)), mParent, SLOT(fetchResult(KJob *)));
+            mParent->connect(job, &ItemFetchJob::result, mParent, [this](KJob *job) {
+                fetchResult(job);
+            });
 
             mFetchCount++;
         }
@@ -128,7 +130,7 @@ public:
         }
     }
 
-    ContactGroupExpandJob *mParent;
+    ContactGroupExpandJob *mParent = nullptr;
     KContacts::ContactGroup mGroup;
     QString mName;
     KContacts::Addressee::List mContacts;
@@ -160,7 +162,9 @@ void ContactGroupExpandJob::start()
         ContactGroupSearchJob *searchJob = new ContactGroupSearchJob(this);
         searchJob->setQuery(ContactGroupSearchJob::Name, d->mName);
         searchJob->setLimit(1);
-        connect(searchJob, SIGNAL(result(KJob *)), this, SLOT(searchResult(KJob *)));
+        connect(searchJob, &ContactGroupSearchJob::result, this, [this](KJob *job) {
+            d->searchResult(job);
+        });
     } else {
         QMetaObject::invokeMethod(this, "resolveGroup", Qt::QueuedConnection);
     }
