@@ -20,11 +20,9 @@
 
 #include "emailaddressselectionwidgettest.h"
 
-#include <kaboutdata.h>
 #include <qapplication.h>
 #include <KComboBox>
 #include <qtextbrowser.h>
-#include <KLocalizedString>
 
 #include <QGridLayout>
 #include <QPushButton>
@@ -44,7 +42,7 @@ MainWidget::MainWidget()
     KComboBox *box = new KComboBox;
     box->addItem(QStringLiteral("Single Selection"));
     box->addItem(QStringLiteral("Multi Selection"));
-    connect(box, static_cast<void (KComboBox::*)(int)>(&KComboBox::activated), this, &MainWidget::selectionModeChanged);
+    connect(box, QOverload<int>::of(&KComboBox::activated), this, &MainWidget::selectionModeChanged);
     layout->addWidget(box, 1, 0);
 
     QPushButton *button = new QPushButton(QStringLiteral("Show Selection"));
@@ -69,9 +67,6 @@ void MainWidget::showSelection()
 
 int main(int argc, char **argv)
 {
-    KAboutData aboutData(QStringLiteral("emailaddressselectionwidgettest"), i18n("Test EmailAddressSelectionWidget"), QStringLiteral("0.1"));
-    KAboutData::setApplicationData(aboutData);
-
     QApplication app(argc, argv);
 
     MainWidget wdg;
