@@ -74,10 +74,10 @@ private:
     void setComboBoxEditable(bool);
     void updateView();
 
-    KComboBox *mView;
+    KComboBox *mView = nullptr;
     KContacts::Addressee mContact;
-    QWidget *mViewport;
-    DisplayType mDisplayType;
+    QWidget *mViewport = nullptr;
+    DisplayType mDisplayType = DisplayType::SimpleName;
     int mAdditionalPopupWidth;
 };
 
