@@ -23,9 +23,7 @@
 #include "mailwidget.h"
 #include <KLocalizedString>
 #include <QHBoxLayout>
-#include <KLineEdit>
 #include <QToolButton>
-#include <QComboBox>
 #include <editor/generalinfoeditor/contactselecttypecombobox.h>
 #include <editor/widgets/preferredlineeditwidget.h>
 
@@ -138,6 +136,14 @@ void MailWidget::setPreferred(bool b)
     mMailEdit->setPreferred(b);
 }
 
+void MailWidget::setReadOnly(bool readOnly)
+{
+    mMailEdit->setReadOnly(readOnly);
+    mMailType->setEnabled(!readOnly);
+    mAddButton->setEnabled(!readOnly);
+    mRemoveButton->setEnabled(!readOnly);
+}
+
 void MailWidget::slotAddMail()
 {
     Q_EMIT addWidget(this);
