@@ -22,7 +22,6 @@
 
 #include "webwidget.h"
 #include <QHBoxLayout>
-#include <KLineEdit>
 #include <QToolButton>
 #include <QUrl>
 #include <KLocalizedString>
@@ -155,6 +154,14 @@ void WebWidget::loadWebSite(const KContacts::ResourceLocatorUrl &url)
     mWebSiteEdit->setText(mUrl.url().toDisplayString());
 }
 
+void WebWidget::setReadOnly(bool readOnly)
+{
+    mWebSiteEdit->setReadOnly(readOnly);
+    mAddButton->setEnabled(!readOnly);
+    mRemoveButton->setEnabled(!readOnly);
+    mWebType->setEnabled(!readOnly);
+}
+
 void WebWidget::slotPreferredChanged()
 {
     Q_EMIT preferredChanged(this);
