@@ -19,8 +19,8 @@
     02110-1301, USA.
 */
 
-#ifndef PREFEREDLINEEDITWIDGET_H
-#define PREFEREDLINEEDITWIDGET_H
+#ifndef PREFERREDLINEEDITWIDGET_H
+#define PREFERREDLINEEDITWIDGET_H
 
 #include <KLineEdit>
 #include <QIcon>
@@ -48,7 +48,7 @@ private:
     bool mPreferred;
     QIcon mIconEnabled;
     QIcon mIconDisabled;
-    QAction *mPreferredAction;
+    QAction *mPreferredAction = nullptr;
 };
 }
-#endif // PREFEREDLINEEDITWIDGET_H
+#endif // PREFERREDLINEEDITWIDGET_H
